@@ -2,6 +2,6 @@ from .lines import lines
 from .scatter import scatter
 from .histograms import histograms
 from .heatMap import heatMap
-from .clusters import cluster_plot
+from .clusters import plot_clusters
 from .bar import bar
 
